@@ -1,6 +1,6 @@
 #
-# Author:: Serdar Sutay (<serdar@opscode.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: Serdar Sutay (<serdar@chef.io>)
+# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -29,7 +29,7 @@ module Ohai
       @hints ||= Hash.new
       return @hints[name] if @hints[name]
 
-      Ohai::Config[:hints_path].each do |path|
+      Ohai.config[:hints_path].each do |path|
         filename = File.join(path, "#{name}.json")
         if File.exist?(filename)
           begin
