@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,14 +22,19 @@ Ohai.plugin(:Filesystem) do
   def get_blk_cmd(attr, have_lsblk)
     if have_lsblk
       attr = 'FSTYPE' if attr == 'TYPE'
-      "lsblk -r -n -o NAME,#{attr}"
+      "lsblk -P -n -o NAME,#{attr}"
     else
       "blkid -s #{attr}"
     end
   end
 
   def get_blk_regex(attr, have_lsblk)
-    have_lsblk ? /^(\S+) (\S+)/ : /^(\S+): #{attr}="(\S+)"/
+    if have_lsblk
+      attr = 'FSTYPE' if attr == 'TYPE'
+      /^NAME="(\S+).*?" #{attr}="(\S+)"/
+    else
+      /^(\S+): #{attr}="(\S+)"/
+    end
   end
 
   def find_device(name)
@@ -60,7 +65,7 @@ Ohai.plugin(:Filesystem) do
         fs[filesystem][:mount] = $6
       end
     end
-    
+
     # Grab filesystem inode data from df
     so = shell_out("df -iP")
     so.stdout.lines do |line|
