@@ -1,6 +1,6 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Copyright:: Copyright (c) 2015-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -28,17 +28,61 @@ Ohai.plugin(:Platform) do
     contents[/Rawhide/i] ? contents[/((\d+) \(Rawhide\))/i, 1].downcase : contents[/release ([\d\.]+)/, 1]
   end
 
+  #
+  # Reads an os-release-info file and parse it into a hash
+  #
+  # @param file [String] the filename to read (e.g. '/etc/os-release')
+  #
+  # @returns [Hash] the file parsed into a Hash or nil
+  #
+  def read_os_release_info(file)
+    return nil unless File.exist?(file)
+    File.read(file).split.inject({}) do |map, line|
+      key, value = line.split('=')
+      map[key] = value.gsub(/\A"|"\Z/, '') if value
+      map
+    end
+  end
+
+  #
+  # Cached /etc/os-release info Hash.  Also has logic for Cisco Nexus
+  # switches that pulls the chained CISCO_RELEASE_INFO file into the Hash (other
+  # distros can also reuse this method safely).
+  #
+  # @returns [Hash] the canonical, cached Hash of /etc/os-release info or nil
+  #
+  def os_release_info
+    @os_release_info ||=
+      begin
+        os_release_info = read_os_release_info('/etc/os-release')
+        cisco_release_info = os_release_info['CISCO_RELEASE_INFO'] if os_release_info
+        if cisco_release_info && File.exist?(cisco_release_info)
+          os_release_info.merge!(read_os_release_info(cisco_release_info))
+        end
+        os_release_info
+      end
+  end
+
+  #
+  # If /etc/os-release indicates we are Cisco based
+  #
+  # @returns [Boolean] if we are Cisco according to /etc/os-release
+  #
+  def os_release_file_is_cisco?
+    File.exist?('/etc/os-release') && os_release_info['CISCO_RELEASE_INFO']
+  end
+
   collect_data(:linux) do
     # platform [ and platform_version ? ] should be lower case to avoid dealing with RedHat/Redhat/redhat matching
-    if File.exists?("/etc/oracle-release")
+    if File.exist?("/etc/oracle-release")
       contents = File.read("/etc/oracle-release").chomp
       platform "oracle"
       platform_version get_redhatish_version(contents)
-    elsif File.exists?("/etc/enterprise-release")
+    elsif File.exist?("/etc/enterprise-release")
       contents = File.read("/etc/enterprise-release").chomp
       platform "oracle"
       platform_version get_redhatish_version(contents)
-    elsif File.exists?("/etc/debian_version")
+    elsif File.exist?("/etc/debian_version")
       # Ubuntu and Debian both have /etc/debian_version
       # Ubuntu should always have a working lsb, debian does not by default
       if lsb[:id] =~ /Ubuntu/i
@@ -48,29 +92,34 @@ Ohai.plugin(:Platform) do
         platform "linuxmint"
         platform_version lsb[:release]
       else
-        if File.exists?("/usr/bin/raspi-config")
+        if File.exist?("/usr/bin/raspi-config")
           platform "raspbian"
         else
           platform "debian"
         end
         platform_version File.read("/etc/debian_version").chomp
       end
-    elsif File.exists?("/etc/parallels-release")
+    elsif File.exist?("/etc/parallels-release")
       contents = File.read("/etc/parallels-release").chomp
       platform get_redhatish_platform(contents)
       platform_version contents.match(/(\d\.\d\.\d)/)[0]
-    elsif File.exists?("/etc/redhat-release")
-      contents = File.read("/etc/redhat-release").chomp
-      platform get_redhatish_platform(contents)
-      platform_version get_redhatish_version(contents)
-    elsif File.exists?("/etc/system-release")
+    elsif File.exist?("/etc/redhat-release")
+      if os_release_file_is_cisco? # Cisco guestshell
+        platform 'nexus_centos'
+        platform_version os_release_info['VERSION']
+      else
+        contents = File.read("/etc/redhat-release").chomp
+        platform get_redhatish_platform(contents)
+        platform_version get_redhatish_version(contents)
+      end
+    elsif File.exist?("/etc/system-release")
       contents = File.read("/etc/system-release").chomp
       platform get_redhatish_platform(contents)
       platform_version get_redhatish_version(contents)
-    elsif File.exists?('/etc/gentoo-release')
+    elsif File.exist?('/etc/gentoo-release')
       platform "gentoo"
       platform_version File.read('/etc/gentoo-release').scan(/(\d+|\.+)/).join
-    elsif File.exists?('/etc/SuSE-release')
+    elsif File.exist?('/etc/SuSE-release')
       suse_release = File.read("/etc/SuSE-release")
       suse_version = suse_release.scan(/VERSION = (\d+)\nPATCHLEVEL = (\d+)/).flatten.join(".")
       suse_version = suse_release[/VERSION = ([\d\.]{2,})/, 1] if suse_version == ""
@@ -80,19 +129,37 @@ Ohai.plugin(:Platform) do
       else
         platform "suse"
       end
-    elsif File.exists?('/etc/slackware-version')
+    elsif File.exist?('/etc/slackware-version')
       platform "slackware"
       platform_version File.read("/etc/slackware-version").scan(/(\d+|\.+)/).join
-    elsif File.exists?('/etc/arch-release')
+    elsif File.exist?('/etc/arch-release')
       platform "arch"
       # no way to determine platform_version in a rolling release distribution
       # kernel release will be used - ex. 2.6.32-ARCH
       platform_version `uname -r`.strip
-    elsif File.exists?('/etc/exherbo-release')
+    elsif File.exist?('/etc/exherbo-release')
       platform "exherbo"
       # no way to determine platform_version in a rolling release distribution
       # kernel release will be used - ex. 3.13
       platform_version `uname -r`.strip
+    elsif File.exist?('/etc/alpine-release')
+      platform "alpine"
+      platform_version File.read("/etc/alpine-release").strip()
+    elsif os_release_file_is_cisco?
+      raise 'unknown Cisco /etc/os-release or /etc/cisco-release ID_LIKE field' if
+        os_release_info['ID_LIKE'].nil? || ! os_release_info['ID_LIKE'].include?('wrlinux')
+
+      case os_release_info['ID']
+      when 'nexus'
+        platform 'nexus'
+      when 'ios_xr'
+        platform 'ios_xr'
+      else
+        raise 'unknown Cisco /etc/os-release or /etc/cisco-release ID field'
+      end
+
+      platform_family 'wrlinux'
+      platform_version os_release_info['VERSION']
     elsif lsb[:id] =~ /RedHat/i
       platform "redhat"
       platform_version lsb[:release]
@@ -115,7 +182,7 @@ Ohai.plugin(:Platform) do
       platform_family "debian"
     when /fedora/, /pidora/
       platform_family "fedora"
-    when /oracle/, /centos/, /redhat/, /scientific/, /enterpriseenterprise/, /amazon/, /xenserver/, /cloudlinux/, /ibm_powerkvm/, /parallels/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
+    when /oracle/, /centos/, /redhat/, /scientific/, /enterpriseenterprise/, /amazon/, /xenserver/, /cloudlinux/, /ibm_powerkvm/, /parallels/, /nexus_centos/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
       platform_family "rhel"
     when /suse/
       platform_family "suse"
@@ -127,6 +194,8 @@ Ohai.plugin(:Platform) do
       platform_family "arch"
     when /exherbo/
       platform_family "exherbo"
+    when /alpine/
+      platform_family "alpine"
     end
   end
 end
