@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
+# Author:: Adam Jacob (<adam@chef.io>)
 # Author:: Bryan McLellan (<btm@loftninjas.org>)
-# Copyright:: Copyright (c) 2008 Opscode, Inc.
+# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
 # Copyright:: Copyright (c) 2009 Bryan McLellan
 # License:: Apache License, Version 2.0
 #
@@ -27,8 +27,8 @@ Ohai.plugin(:PS) do
     command[:ps] = 'ps -ef'
   end
 
-  collect_data(:freebsd, :netbsd, :openbsd) do
+  collect_data(:freebsd, :netbsd, :openbsd, :dragonflybsd) do
     # ps -e requires procfs
-    command[:ps] = 'ps -ax'
+    command[:ps] = 'ps -axww'
   end
 end
