@@ -16,25 +16,29 @@
 # limitations under the License.
 #
 
-require "sigar"
+Ohai.plugin(:CPU) do
+  provides "cpu"
 
-sigar = Sigar.new
+  collect_data(:hpux, :default) do
+    require 'sigar'
 
-provides "cpu"
+    sigar = Sigar.new
 
-cpuinfo = Mash.new
-ix = 0
+    cpuinfo = Mash.new
+    ix = 0
 
-sigar.cpu_info_list.each do |info|
-  current_cpu = ix.to_s
-  ix += 1
-  cpuinfo[current_cpu] = Mash.new
-  cpuinfo[current_cpu]["vendor_id"] = info.vendor
-  cpuinfo[current_cpu]["model"] = info.model
-  cpuinfo[current_cpu]["mhz"] = info.mhz.to_s
-  cpuinfo[current_cpu]["cache_size"] = info.cache_size.to_s
-  cpuinfo[:total] = info.total_cores
-  cpuinfo[:real] = info.total_sockets
+    sigar.cpu_info_list.each do |info|
+      current_cpu = ix.to_s
+      ix += 1
+      cpuinfo[current_cpu] = Mash.new
+      cpuinfo[current_cpu]["vendor_id"] = info.vendor
+      cpuinfo[current_cpu]["model"] = info.model
+      cpuinfo[current_cpu]["mhz"] = info.mhz.to_s
+      cpuinfo[current_cpu]["cache_size"] = info.cache_size.to_s
+      cpuinfo[:total] = info.total_cores
+      cpuinfo[:real] = info.total_sockets
+    end
+
+    cpu cpuinfo
+  end
 end
-
-cpu cpuinfo
