@@ -19,6 +19,14 @@ Ohai.plugin(:Memory) do
 
   collect_data(:solaris2) do
     memory Mash.new
-    memory[:total] = shell_out("prtconf -m").stdout.to_i
+    memory[:swap] = Mash.new
+    meminfo =  shell_out("prtconf | grep Memory").stdout
+    memory[:total] = "#{meminfo.split[2].to_i * 1024}kB"
+    
+    tokens = shell_out("swap -s").stdout.strip.split
+    used_swap = tokens[8][0..-1].to_i #strip k from end
+    free_swap = tokens[10][0..-1].to_i #strip k from end
+    memory[:swap][:total] = "#{used_swap + free_swap}kB"
+    memory[:swap][:free] = "#{free_swap}kB"
   end
 end
