@@ -1,6 +1,6 @@
 #
-# Author:: Claire McQuin (<claire@opscode.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: Claire McQuin (<claire@chef.io>)
+# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you
@@ -48,6 +48,8 @@ module Ohai
         end
       rescue Ohai::Exceptions::Error
         raise
+      rescue SystemExit # abort or exit from plug-in should exit Ohai with failure code
+        raise
       rescue Exception,Errno::ENOENT => e
         Ohai::Log.debug("Plugin #{plugin.name} threw exception #{e.inspect} #{e.backtrace.join("\n")}")
       end
