@@ -1,6 +1,7 @@
 #
 # Author:: Prabhu Das (<prabhu.das@clogeny.com>)
-# Copyright:: Copyright (c) 2013 Opscode, Inc.
+# Author:: Isa Farnik (<isa@chef.io>)
+# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,11 +18,12 @@
 
 require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
 
-describe Ohai::System, "Aix hostname plugin" do
+describe Ohai::System, "AIX hostname plugin" do
   before(:each) do
     @plugin = get_plugin("hostname")
     allow(@plugin).to receive(:collect_os).and_return(:aix)
-    allow(@plugin).to receive(:from_cmd).with("hostname").and_return("aix_admin")
+    allow(@plugin).to receive(:from_cmd).with("hostname -s").and_return("aix_admin")
+    allow(@plugin).to receive(:from_cmd).with("hostname").and_return("aix_admin.ponyville.com")
     @plugin.run
   end
 
