@@ -1,6 +1,6 @@
 #
 # Author:: Matthew Kent (<mkent@magoazul.com>)
-# Copyright:: Copyright (c) 2011 Opscode, Inc.
+# Copyright:: Copyright (c) 2011-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,23 +19,23 @@
 require File.expand_path(File.dirname(__FILE__) + '/../../../spec_helper.rb')
 
 describe Ohai::System, "Linux filesystem plugin" do
+  let(:plugin) { get_plugin("linux/filesystem") }
   before(:each) do
-    @plugin = get_plugin("linux/filesystem")
-    allow(@plugin).to receive(:collect_os).and_return(:linux)
+    allow(plugin).to receive(:collect_os).and_return(:linux)
 
-    allow(@plugin).to receive(:shell_out).with("df -P").and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("df -iP").and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("df -P").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("df -iP").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, "", ""))
     allow(File).to receive(:exist?).with("/bin/lsblk").and_return(false)
-    allow(@plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, "", ""))
+    allow(plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, "", ""))
 
-    allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,FSTYPE").
+    allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,FSTYPE").
       and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,UUID").
+    allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,UUID").
       and_return(mock_shell_out(0, "", ""))
-    allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,LABEL").
+    allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,LABEL").
       and_return(mock_shell_out(0, "", ""))
 
     allow(File).to receive(:exist?).with("/proc/mounts").and_return(false)
@@ -50,6 +50,7 @@ describe Ohai::System, "Linux filesystem plugin" do
        sys.vg-usr.lv
        sys.vg-var.lv
        sys.vg-home.lv
+       debian--7-root
     }.each do |name|
       allow(File).to receive(:exist?).with("/dev/#{name}").and_return(false)
       allow(File).to receive(:exist?).with("/dev/mapper/#{name}").and_return(true)
@@ -71,7 +72,7 @@ tmpfs                  2030944      2960   2027984       1% /dev/shm
 /dev/mapper/sys.vg-var.lv  19223252   3436556  14810212      19% /var
 /dev/md0                960492     36388    875312       4% /boot
 DF
-      allow(@plugin).to receive(:shell_out).with("df -P").and_return(mock_shell_out(0, @stdout, ""))
+      allow(plugin).to receive(:shell_out).with("df -P").and_return(mock_shell_out(0, @stdout, ""))
       
       @inode_stdout = <<-DFi
 Filesystem      Inodes  IUsed   IFree IUse% Mounted on
@@ -81,53 +82,53 @@ tmpfs           126922    273  126649    1% /run
 none            126922      1  126921    1% /run/lock
 none            126922      1  126921    1% /run/shm
 DFi
-      allow(@plugin).to receive(:shell_out).with("df -iP").and_return(mock_shell_out(0, @inode_stdout, ""))
+      allow(plugin).to receive(:shell_out).with("df -iP").and_return(mock_shell_out(0, @inode_stdout, ""))
     end
 
     it "should run df -P and df -iP" do
-      expect(@plugin).to receive(:shell_out).ordered.with("df -P").and_return(mock_shell_out(0, @stdout, ""))
-      expect(@plugin).to receive(:shell_out).ordered.with("df -iP").and_return(mock_shell_out(0, @inode_stdout, ""))
-      @plugin.run
+      expect(plugin).to receive(:shell_out).ordered.with("df -P").and_return(mock_shell_out(0, @stdout, ""))
+      expect(plugin).to receive(:shell_out).ordered.with("df -iP").and_return(mock_shell_out(0, @inode_stdout, ""))
+      plugin.run
     end
 
     it "should set kb_size to value from df -P" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_size]).to eq("97605057")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_size]).to eq("97605057")
     end
 
     it "should set kb_used to value from df -P" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_used]).to eq("53563253")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_used]).to eq("53563253")
     end
 
     it "should set kb_available to value from df -P" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_available]).to eq("44041805")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:kb_available]).to eq("44041805")
     end
 
     it "should set percent_used to value from df -P" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:percent_used]).to eq("56%")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:percent_used]).to eq("56%")
     end
 
     it "should set mount to value from df -P" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
     end
     
     it "should set total_inodes to value from df -iP" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:total_inodes]).to eq("124865")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:total_inodes]).to eq("124865")
     end
     
     it "should set inodes_used to value from df -iP" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:inodes_used]).to eq("380")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:inodes_used]).to eq("380")
     end
     
     it "should set inodes_available to value from df -iP" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:inodes_available]).to eq("124485")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:inodes_available]).to eq("124485")
     end
   end
 
@@ -150,27 +151,27 @@ devpts on /dev/pts type devpts (rw,noexec,nosuid,gid=5,mode=620)
 fusectl on /sys/fs/fuse/connections type fusectl (rw)
 binfmt_misc on /proc/sys/fs/binfmt_misc type binfmt_misc (rw,noexec,nosuid,nodev)
 MOUNT
-      allow(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @stdout, ""))
+      allow(plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @stdout, ""))
     end
 
     it "should run mount" do
-      expect(@plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      expect(plugin).to receive(:shell_out).with("mount").and_return(mock_shell_out(0, @stdout, ""))
+      plugin.run
     end
 
     it "should set mount to value from mount" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
     end
 
     it "should set fs_type to value from mount" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:fs_type]).to eq("xfs")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:fs_type]).to eq("xfs")
     end
 
     it "should set mount_options to an array of values from mount" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount_options]).to eq([ "ro", "noatime" ])
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount_options]).to eq([ "ro", "noatime" ])
     end
   end
 
@@ -189,18 +190,19 @@ MOUNT
 /dev/mapper/sys.vg-usr.lv: TYPE=\"ext4\" 
 /dev/mapper/sys.vg-var.lv: TYPE=\"ext4\" 
 /dev/mapper/sys.vg-home.lv: TYPE=\"xfs\" 
+/dev/mapper/debian--7-root: TYPE=\"ext4\" 
 BLKID_TYPE
-      allow(@plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, @stdout, ""))
+      allow(plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, @stdout, ""))
     end
 
     it "should run blkid -s TYPE" do
-      expect(@plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      expect(plugin).to receive(:shell_out).with("blkid -s TYPE").and_return(mock_shell_out(0, @stdout, ""))
+      plugin.run
     end
 
-    it "should set kb_size to value from blkid -s TYPE" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/md1"][:fs_type]).to eq("LVM2_member")
+    it "should set fs_type to value from blkid -s TYPE" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/md1"][:fs_type]).to eq("LVM2_member")
     end
   end
 
@@ -208,32 +210,38 @@ BLKID_TYPE
     before(:each) do
       allow(File).to receive(:exist?).with("/bin/lsblk").and_return(true)
       @stdout = <<-BLKID_TYPE
-sdb1 linux_raid_member 
-sdb2 linux_raid_member 
-sda1 linux_raid_member 
-sda2 linux_raid_member 
-md0 ext3 
-md1 LVM2_member 
-sys.vg-root.lv ext4 
-sys.vg-swap.lv swap 
-sys.vg-tmp.lv ext4 
-sys.vg-usr.lv ext4 
-sys.vg-var.lv ext4 
-sys.vg-home.lv xfs 
+NAME="sdb1" FSTYPE="linux_raid_member" 
+NAME="sdb2" FSTYPE="linux_raid_member" 
+NAME="sda1" FSTYPE="linux_raid_member" 
+NAME="sda2" FSTYPE="linux_raid_member" 
+NAME="md0" FSTYPE="ext3" 
+NAME="md1" FSTYPE="LVM2_member" 
+NAME="sys.vg-root.lv" FSTYPE="ext4" 
+NAME="sys.vg-swap.lv" FSTYPE="swap" 
+NAME="sys.vg-tmp.lv" FSTYPE="ext4" 
+NAME="sys.vg-usr.lv" FSTYPE="ext4" 
+NAME="sys.vg-var.lv" FSTYPE="ext4" 
+NAME="sys.vg-home.lv" FSTYPE="xfs" 
+NAME="debian--7-root (dm-0)" FSTYPE="ext4" 
 BLKID_TYPE
-      allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,FSTYPE").
+      allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,FSTYPE").
         and_return(mock_shell_out(0, @stdout, ""))
     end
 
-    it "should run lsblk -r -n -o NAME,FSTYPE" do
-      expect(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,FSTYPE").
+    it "should run lsblk -P -n -o NAME,FSTYPE" do
+      expect(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,FSTYPE").
         and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      plugin.run
     end
 
-    it "should set kb_size to value from lsblk -r -n -o NAME,FSTYPE" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/md1"][:fs_type]).to eq("LVM2_member")
+    it "should set fs_type to value from lsblk -P -n -o NAME,FSTYPE" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/md1"][:fs_type]).to eq("LVM2_member")
+    end
+
+    it "should ignore extra info in name and set fs_type to value from lsblk -P -n -o NAME,FSTYPE" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/debian--7-root"][:fs_type]).to eq("ext4")
     end
   end
 
@@ -252,18 +260,19 @@ BLKID_TYPE
 /dev/mapper/sys.vg-usr.lv: UUID=\"26ec33c5-d00b-4f88-a550-492def013bbc\" 
 /dev/mapper/sys.vg-var.lv: UUID=\"6b559c35-7847-4ae2-b512-c99012d3f5b3\" 
 /dev/mapper/sys.vg-home.lv: UUID=\"d6efda02-1b73-453c-8c74-7d8dee78fa5e\" 
+/dev/mapper/debian--7-root: UUID=\"09187faa-3512-4505-81af-7e86d2ccb99a\" 
 BLKID_UUID
-      allow(@plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, @stdout, ""))
+      allow(plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, @stdout, ""))
     end
 
     it "should run blkid -s UUID" do
-      expect(@plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      expect(plugin).to receive(:shell_out).with("blkid -s UUID").and_return(mock_shell_out(0, @stdout, ""))
+      plugin.run
     end
 
-    it "should set kb_size to value from blkid -s UUID" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/sda2"][:uuid]).to eq("e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa")
+    it "should set uuid to value from blkid -s UUID" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/sda2"][:uuid]).to eq("e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa")
     end
   end
 
@@ -271,35 +280,43 @@ BLKID_UUID
     before(:each) do
       allow(File).to receive(:exist?).with("/bin/lsblk").and_return(true)
       @stdout = <<-BLKID_UUID
-sdb1 bd1197e0-6997-1f3a-e27e-7801388308b5 
-sdb2 e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa 
-sda1 bd1197e0-6997-1f3a-e27e-7801388308b5 
-sda2 e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa 
-md0 37b8de8e-0fe3-4b5a-b9b4-dde33e19bb32 
-md1 YsIe0R-fj1y-LXTd-imla-opKo-OuIe-TBoxSK 
-sys.vg-root.lv 7742d14b-80a3-4e97-9a32-478be9ea9aea 
-sys.vg-swap.lv 9bc2e515-8ddc-41c3-9f63-4eaebde9ce96 
-sys.vg-tmp.lv 74cf7eb9-428f-479e-9a4a-9943401e81e5 
-sys.vg-usr.lv 26ec33c5-d00b-4f88-a550-492def013bbc 
-sys.vg-var.lv 6b559c35-7847-4ae2-b512-c99012d3f5b3 
-sys.vg-home.lv d6efda02-1b73-453c-8c74-7d8dee78fa5e 
+NAME="sdb1" UUID="bd1197e0-6997-1f3a-e27e-7801388308b5" 
+NAME="sdb2" UUID="e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa" 
+NAME="sda1" UUID="bd1197e0-6997-1f3a-e27e-7801388308b5" 
+NAME="sda2" UUID="e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa" 
+NAME="md0" UUID="37b8de8e-0fe3-4b5a-b9b4-dde33e19bb32" 
+NAME="md1" UUID="YsIe0R-fj1y-LXTd-imla-opKo-OuIe-TBoxSK" 
+NAME="sys.vg-root.lv" UUID="7742d14b-80a3-4e97-9a32-478be9ea9aea" 
+NAME="sys.vg-swap.lv" UUID="9bc2e515-8ddc-41c3-9f63-4eaebde9ce96" 
+NAME="sys.vg-tmp.lv" UUID="74cf7eb9-428f-479e-9a4a-9943401e81e5" 
+NAME="sys.vg-usr.lv" UUID="26ec33c5-d00b-4f88-a550-492def013bbc" 
+NAME="sys.vg-var.lv" UUID="6b559c35-7847-4ae2-b512-c99012d3f5b3" 
+NAME="sys.vg-home.lv" UUID="d6efda02-1b73-453c-8c74-7d8dee78fa5e" 
+NAME="debian--7-root (dm-0)" UUID="09187faa-3512-4505-81af-7e86d2ccb99a" 
 BLKID_UUID
-      allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,UUID").
+      allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,UUID").
         and_return(mock_shell_out(0, @stdout, ""))
     end
 
-    it "should run lsblk -r -n -o NAME,UUID" do
-      expect(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,UUID").
+    it "should run lsblk -P -n -o NAME,UUID" do
+      expect(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,UUID").
         and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      plugin.run
     end
 
-    it "should set kb_size to value from lsblk -r -n -o NAME,UUID" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/sda2"][:uuid]).to eq(
+    it "should set uuid to value from lsblk -P -n -o NAME,UUID" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/sda2"][:uuid]).to eq(
         "e36d933e-e5b9-cfe5-6845-1f84d0f7fbfa"
       )
     end
+
+    it "should ignore extra info in name and set uuid to value from lsblk -P -n -o NAME,UUID" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/debian--7-root"][:uuid]).to eq(
+        "09187faa-3512-4505-81af-7e86d2ccb99a"
+      )
+    end
   end
 
   describe "when gathering filesystem label data from blkid" do
@@ -315,18 +332,19 @@ BLKID_UUID
 /dev/mapper/sys.vg-usr.lv: LABEL=\"/usr\" 
 /dev/mapper/sys.vg-var.lv: LABEL=\"/var\" 
 /dev/mapper/sys.vg-home.lv: LABEL=\"/home\" 
+/dev/mapper/debian--7-root: LABEL=\"root\" 
 BLKID_LABEL
-      allow(@plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, @stdout, ""))
+      allow(plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, @stdout, ""))
     end
 
     it "should run blkid -s LABEL" do
-      expect(@plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      expect(plugin).to receive(:shell_out).with("blkid -s LABEL").and_return(mock_shell_out(0, @stdout, ""))
+      plugin.run
     end
 
-    it "should set kb_size to value from blkid -s LABEL" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/md0"][:label]).to eq("/boot")
+    it "should set label to value from blkid -s LABEL" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/md0"][:label]).to eq("/boot")
     end
   end
 
@@ -334,30 +352,36 @@ BLKID_LABEL
     before(:each) do
       allow(File).to receive(:exist?).with("/bin/lsblk").and_return(true)
       @stdout = <<-BLKID_LABEL
-sda1 fuego:0 
-sda2 fuego:1 
-sdb1 fuego:0 
-sdb2 fuego:1 
-md0 /boot 
-sys.vg-root.lv / 
-sys.vg-tmp.lv /tmp 
-sys.vg-usr.lv /usr 
-sys.vg-var.lv /var 
-sys.vg-home.lv /home 
+NAME="sda1" LABEL="fuego:0" 
+NAME="sda2" LABEL="fuego:1" 
+NAME="sdb1" LABEL="fuego:0" 
+NAME="sdb2" LABEL="fuego:1" 
+NAME="md0" LABEL="/boot" 
+NAME="sys.vg-root.lv" LABEL="/" 
+NAME="sys.vg-tmp.lv" LABEL="/tmp" 
+NAME="sys.vg-usr.lv" LABEL="/usr" 
+NAME="sys.vg-var.lv" LABEL="/var" 
+NAME="sys.vg-home.lv" LABEL="/home" 
+NAME="debian--7-root (dm-0)" LABEL="root" 
 BLKID_LABEL
-      allow(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,LABEL").
+      allow(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,LABEL").
         and_return(mock_shell_out(0, @stdout, ""))
     end
 
-    it "should run blkid -s LABEL" do
-      expect(@plugin).to receive(:shell_out).with("lsblk -r -n -o NAME,LABEL").
+    it "should run lsblk -P -n -o NAME,LABEL" do
+      expect(plugin).to receive(:shell_out).with("lsblk -P -n -o NAME,LABEL").
         and_return(mock_shell_out(0, @stdout, ""))
-      @plugin.run
+      plugin.run
     end
 
-    it "should set kb_size to value from blkid -s LABEL" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/md0"][:label]).to eq("/boot")
+    it "should set label to value from lsblk -P -n -o NAME,LABEL" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/md0"][:label]).to eq("/boot")
+    end
+
+    it "should ignore extra info in name and set label to value from lsblk -P -n -o NAME,LABEL" do
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/debian--7-root"][:label]).to eq("root")
     end
   end
 
@@ -395,18 +419,18 @@ MOUNTS
     end
 
     it "should set mount to value from /proc/mounts" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount]).to eq("/special")
     end
   
     it "should set fs_type to value from /proc/mounts" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:fs_type]).to eq("xfs")
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:fs_type]).to eq("xfs")
     end
   
     it "should set mount_options to an array of values from /proc/mounts" do
-      @plugin.run
-      expect(@plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount_options]).to eq([ "ro", "noatime", "attr2", "noquota" ])
+      plugin.run
+      expect(plugin[:filesystem]["/dev/mapper/sys.vg-special.lv"][:mount_options]).to eq([ "ro", "noatime", "attr2", "noquota" ])
     end
   end
 
