@@ -1,7 +1,7 @@
 #
 #  Author:: Caleb Tennis <caleb.tennis@gmail.com>
 #  Author:: Chris Read <chris.read@gmail.com>
-#  Copyright:: Copyright (c) 2011 Opscode, Inc.
+#  Copyright:: Copyright (c) 2011-2016 Chef Software, Inc.
 #  License:: Apache License, Version 2.0
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
@@ -298,6 +298,31 @@ fe80::21c:eff:fe12:3456 dev eth0.153 lladdr 00:1c:0e:30:28:00 router REACHABLE
 '
   }
 
+  let(:linux_ethtool) {
+'Settings for eth0:
+        Supported ports: [ FIBRE ]
+        Supported link modes:   1000baseT/Full
+                                10000baseT/Full
+        Supported pause frame use: No
+        Supports auto-negotiation: Yes
+        Advertised link modes:  1000baseT/Full
+                                10000baseT/Full
+        Advertised pause frame use: No
+        Advertised auto-negotiation: Yes
+        Speed: 10000Mb/s
+        Duplex: Full
+        Port: FIBRE
+        PHYAD: 0
+        Transceiver: external
+        Auto-negotiation: on
+        Supports Wake-on: d
+        Wake-on: d
+        Current message level: 0x00000007 (7)
+                               drv probe link
+        Link detected: yes
+'
+  }
+
   before(:each) do
     allow(plugin).to receive(:collect_os).and_return(:linux)
 
@@ -305,12 +330,13 @@ fe80::21c:eff:fe12:3456 dev eth0.153 lladdr 00:1c:0e:30:28:00 router REACHABLE
     allow(plugin).to receive(:shell_out).with("ip -d -s link").and_return(mock_shell_out(0, linux_ip_link_s_d, ""))
     allow(plugin).to receive(:shell_out).with("ip -f inet neigh show").and_return(mock_shell_out(0, linux_ip_neighbor_show, ""))
     allow(plugin).to receive(:shell_out).with("ip -f inet6 neigh show").and_return(mock_shell_out(0, linux_ip_inet6_neighbor_show, ""))
-    allow(plugin).to receive(:shell_out).with("ip -o -f inet route show").and_return(mock_shell_out(0, linux_ip_route, ""))
-    allow(plugin).to receive(:shell_out).with("ip -o -f inet6 route show").and_return(mock_shell_out(0, linux_ip_route_inet6, ""))
+    allow(plugin).to receive(:shell_out).with("ip -o -f inet route show table main").and_return(mock_shell_out(0, linux_ip_route, ""))
+    allow(plugin).to receive(:shell_out).with("ip -o -f inet6 route show table main").and_return(mock_shell_out(0, linux_ip_route_inet6, ""))
 
     allow(plugin).to receive(:shell_out).with("route -n").and_return(mock_shell_out(0, linux_route_n, ""))
     allow(plugin).to receive(:shell_out).with("ifconfig -a").and_return(mock_shell_out(0, linux_ifconfig, ""))
     allow(plugin).to receive(:shell_out).with("arp -an").and_return(mock_shell_out(0, linux_arp_an, ""))
+    allow(plugin).to receive(:shell_out).with(/ethtool/).and_return(mock_shell_out(0, linux_ethtool, ""))
   end
 
   describe "#iproute2_binary_available?" do
@@ -323,11 +349,23 @@ fe80::21c:eff:fe12:3456 dev eth0.153 lladdr 00:1c:0e:30:28:00 router REACHABLE
     end
   end
 
+  describe "#find_ethtool_binary" do
+    ["/sbin/ethtool", "/usr/sbin/ethtool"].each do |path|
+      it "accepts #{path}" do
+        allow(File).to receive(:exist?).and_return(false)
+        allow(File).to receive(:exist?).with(path).and_return(true)
+        expect(plugin.find_ethtool_binary).to end_with("/ethtool")
+      end
+    end
+  end
+
+
   ["ifconfig","iproute2"].each do |network_method|
 
     describe "gathering IP layer address info via #{network_method}" do
       before(:each) do
         allow(plugin).to receive(:iproute2_binary_available?).and_return( network_method == "iproute2" )
+        allow(plugin).to receive(:find_ethtool_binary).and_return( '/sbin/ethtool' )
         plugin.run
       end
 
@@ -340,6 +378,15 @@ fe80::21c:eff:fe12:3456 dev eth0.153 lladdr 00:1c:0e:30:28:00 router REACHABLE
         expect(plugin['network']['interfaces'].keys.sort).to eq(["eth0", "eth0.11", "eth0.151", "eth0.152", "eth0.153", "eth0:5", "eth3", "foo:veth0@eth0", "lo", "ovs-system",  "tun0", "venet0", "venet0:0", "xapi1"])
       end
 
+      it "detects the layer one details of an ethernet interface" do
+        expect(plugin['network']['interfaces']['eth0']['link_speed']).to eq(10000)
+        expect(plugin['network']['interfaces']['eth0']['duplex']).to eq('Full')
+        expect(plugin['network']['interfaces']['eth0']['port']).to eq('FIBRE')
+        expect(plugin['network']['interfaces']['eth0']['transceiver']).to eq('external')
+        expect(plugin['network']['interfaces']['eth0']['auto_negotiation']).to eq('on')
+        expect(plugin['network']['interfaces']['eth0']['mdi_x']).to be_nil
+      end
+
       it "detects the ipv4 addresses of the ethernet interface" do
         expect(plugin['network']['interfaces']['eth0']['addresses'].keys).to include('10.116.201.76')
         expect(plugin['network']['interfaces']['eth0']['addresses']['10.116.201.76']['netmask']).to eq('255.255.255.0')
@@ -547,6 +594,7 @@ Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
     before(:each) do
       allow(File).to receive(:exist?).with("/sbin/ip").and_return(true) # iproute2 only
       allow(File).to receive(:exist?).with("/proc/net/if_inet6").and_return(true) # ipv6 is enabled
+      allow(File).to receive(:exist?).with("/sbin/ethtool").and_return(true) # ethtool is available
       plugin.run
     end
 
@@ -615,7 +663,14 @@ Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
         expect(plugin['network']['interfaces']['eth0.11']['routes']).to include Mash.new( :destination => "default", :via => "1111:2222:3333:4444::1", :metric => "1024", :family => "inet6")
       end
 
-      describe "when there isn't a source field in route entries " do
+      describe "when there isn't a source field in route entries and no ipv6 default routes" do
+        let(:linux_ip_route_inet6) {
+'fe80::/64 dev eth0  proto kernel  metric 256
+fe80::/64 dev eth0.11  proto kernel  metric 256
+1111:2222:3333:4444::/64 dev eth0.11  metric 1024  expires 86023sec
+'
+        }
+
         before(:each) do
           plugin.run
         end
@@ -750,7 +805,7 @@ default via 1111:2222:3333:4444::ffff dev eth0.11  metric 1023 src 1111:2222:333
         end
       end
 
-      describe "when there's a source field in a local route entry " do
+      describe "when there's a source field in a local route entry but it isnt in the default route" do
         let(:linux_ip_route) {
 '10.116.201.0/24 dev eth0  proto kernel  src 10.116.201.76
 192.168.5.0/24 dev eth0  proto kernel  src 192.168.5.1
@@ -780,18 +835,34 @@ default via 1111:2222:3333:4444::1 dev eth0.11  metric 1024
           expect(plugin['ipaddress']).to eq("10.116.201.76")
         end
 
+        # without a source address on the default route we cannot pick the an ipv6 address from the interface
+        # In the future an RFC6724 compliant process should choose ip6address in the network plugin
+        it "does not set ip6address" do
+          plugin.run
+          expect(plugin['ip6address']).to eq(nil)
+        end
+
+        context "with only ipv6 routes" do
+          let(:linux_ip_route) { '' }
+
+          it "sets macaddress to the mac address of the ip6 default interface" do
+            expect(plugin['macaddress']).to eq("00:AA:BB:CC:DD:EE")
+          end
+        end
+
         describe "when about to set macaddress" do
           it "sets macaddress" do
             plugin.run
             expect(plugin['macaddress']).to eq("12:31:3D:02:BE:A2")
           end
 
-          describe "when then interface has the NOARP flag" do
+          context "when then ipv4 interface has the NOARP flag and no ipv6 routes exist" do
             let(:linux_ip_route) {
 '10.118.19.1 dev tun0 proto kernel  src 10.118.19.39
 default via 172.16.19.1 dev tun0
 '
             }
+            let(:linux_ip_route_inet6) { '' }
 
             it "completes the run" do
               expect(Ohai::Log).not_to receive(:debug).with(/Plugin linux::network threw exception/)
@@ -805,11 +876,6 @@ default via 172.16.19.1 dev tun0
             end
           end
         end
-
-        it "sets ip6address" do
-          plugin.run
-          expect(plugin['ip6address']).to eq("1111:2222:3333:4444::3")
-        end
       end
 
       describe "with a link level default route" do
@@ -888,6 +954,49 @@ fe80::/64 dev eth0.11  proto kernel  metric 256
         end
       end
 
+      describe "with openvz setup" do
+        let(:linux_ip_route) {'default dev venet0  scope link' }
+        let(:linux_ip_addr) {'1: lo: <LOOPBACK,UP,LOWER_UP> mtu 65536 qdisc noqueue state UNKNOWN
+    link/loopback 00:00:00:00:00:00 brd 00:00:00:00:00:00
+    inet 127.0.0.1/8 scope host lo
+    inet6 ::1/128 scope host
+       valid_lft forever preferred_lft forever
+2: venet0: <BROADCAST,POINTOPOINT,NOARP,UP,LOWER_UP> mtu 1500 qdisc noqueue state UNKNOWN
+    link/void
+    inet 127.0.0.2/32 scope host venet0
+    inet 10.116.201.76/24 brd 10.116.201.255 scope global venet0:0
+    inet6 2001:44b8:4160:8f00:a00:27ff:fe13:eacd/64 scope global dynamic
+       valid_lft 6128sec preferred_lft 2526sec
+'}
+        # We don't have the corresponding ipv6 data for these tests
+        let(:linux_ip_route_inet6) { '' }
+        let(:linux_ip_inet6_neighbor_show) { '' }
+
+        before(:each) do
+          allow(plugin).to receive(:is_openvz?).and_return true
+          allow(plugin).to receive(:is_openvz_host?).and_return false
+          plugin.run
+        end
+
+        it "completes the run" do
+          expect(Ohai::Log).not_to receive(:debug).with(/Plugin linux::network threw exception/)
+          expect(plugin['network']).not_to be_nil
+        end
+
+        it "sets default ipv4 interface and gateway" do
+          expect(plugin['network']['default_interface']).to eq('venet0:0')
+          expect(plugin['network']['default_gateway']).to eq('0.0.0.0')
+        end
+
+        it "sets correct routing information" do
+          expect(plugin['network']['interfaces']['venet0:0']['routes']).to eq([Mash.new( :destination => "default", :family => "inet", :scope => "link" )])
+        end
+
+        it "sets correct address information" do
+          expect(plugin['network']['interfaces']['venet0:0']['addresses']).to eq("10.116.201.76" => Mash.new(:family => 'inet', :prefixlen => '24', :netmask =>'255.255.255.0', :broadcast => '10.116.201.255', :scope => "Global"))
+        end
+      end
+
       describe "with irrelevant routes (container setups)" do
         let(:linux_ip_route) {
 '10.116.201.0/26 dev eth0 proto kernel  src 10.116.201.39
