@@ -26,8 +26,8 @@ def it_doesnt_fail
   end
 end
 
+# basic sanity check that is called in all describes below
 def it_populates_ipaddress_attributes
-
   source = caller[0]
 
   it "populates ipaddress, macaddress and ip6address" do
@@ -43,11 +43,11 @@ def it_populates_ipaddress_attributes
       raise
     end
   end
-
 end
 
 describe Ohai::System, "Network Plugin" do
 
+  # output of network plugins on particular platforms to mock plugin runs
   basic_data = {
     "freebsd" => {
       "network" => {
@@ -57,7 +57,9 @@ describe Ohai::System, "Network Plugin" do
             "number" => "0",
             "flags" => ["UP", "BROADCAST", "RUNNING", "SIMPLEX", "MULTICAST"],
             "addresses" => {
-              "00:00:24:c9:5e:b8" => {"family" => "lladdr"},
+              "00:00:24:c9:5e:b8" => {
+                "family" => "lladdr"
+              },
               "fe80::200:24ff:fec9:5eb8" => {
                 "family" => "inet6",
                 "zoneid" => "vr0",
@@ -80,7 +82,9 @@ describe Ohai::System, "Network Plugin" do
             "number" => "1",
             "flags" => ["UP", "BROADCAST", "RUNNING", "PROMISC", "SIMPLEX", "MULTICAST"],
             "addresses" => {
-              "00:00:24:c9:5e:b9" => {"family" => "lladdr"},
+              "00:00:24:c9:5e:b9" => {
+                "family" => "lladdr"
+              },
               "fe80::200:24ff:fec9:5eb9" => {
                 "family" => "inet6",
                 "zoneid" => "vr1",
@@ -94,7 +98,9 @@ describe Ohai::System, "Network Plugin" do
             "number" => "2",
             "flags" => ["UP", "BROADCAST", "RUNNING", "PROMISC", "SIMPLEX", "MULTICAST"],
             "addresses" => {
-              "00:00:24:c9:5e:ba" => {"family" => "lladdr"},
+              "00:00:24:c9:5e:ba" => {
+                "family" => "lladdr"
+              },
               "fe80::200:24ff:fec9:5eba" => {
                 "family" => "inet6",
                 "zoneid" => "vr2",
@@ -108,7 +114,9 @@ describe Ohai::System, "Network Plugin" do
             "number" => "3",
             "flags" => ["UP", "BROADCAST", "RUNNING", "PROMISC", "SIMPLEX", "MULTICAST"],
             "addresses" => {
-              "00:00:24:c9:5e:bb" => {"family" => "lladdr"},
+              "00:00:24:c9:5e:bb" => {
+                "family" => "lladdr"
+              },
               "fe80::200:24ff:fec9:5ebb" => {
                 "family" => "inet6",
                 "zoneid" => "vr3",
@@ -128,8 +136,14 @@ describe Ohai::System, "Network Plugin" do
             "number" => "0",
             "flags" => ["UP", "LOOPBACK", "RUNNING", "MULTICAST"],
             "addresses" => {
-              "127.0.0.1" => {"family" => "inet", "netmask" => "255.0.0.0"},
-              "::1" => {"family" => "inet6", "prefixlen" => "128"},
+              "127.0.0.1" => {
+                "family" => "inet",
+                "netmask" => "255.0.0.0"
+              },
+              "::1" => {
+                "family" => "inet6",
+                "prefixlen" => "128"
+              },
               "fe80::1" => {
                 "family" => "inet6",
                 "zoneid" => "lo0",
@@ -143,13 +157,18 @@ describe Ohai::System, "Network Plugin" do
             "number" => "0",
             "flags" => ["LEARNING", "DISCOVER", "AUTOEDGE", "AUTOPTP"],
             "addresses" => {
-              "02:20:6f:d2:c4:00" => {"family"=>"lladdr"},
+              "02:20:6f:d2:c4:00" => {
+                "family"=>"lladdr"
+              },
               "192.168.2.1" => {
                 "family" => "inet",
                 "netmask" => "255.255.255.0",
                 "broadcast" => "192.168.2.255"
               },
-              "2001:470:d:cb4::1" => {"family" => "inet6", "prefixlen" => "64"},
+              "2001:470:d:cb4::1" => {
+                "family" => "inet6",
+                "prefixlen" => "64"
+              },
               "fe80::cafe:babe:dead:beef" => {
                 "family" => "inet6",
                 "zoneid" => "bridge0",
@@ -183,12 +202,14 @@ describe Ohai::System, "Network Plugin" do
           }
         },
         "default_gateway" => "76.91.0.1",
-        "default_interface" => "vr0"
+        "default_interface" => "vr0",
+        "default_inet6_gateway" => "2001:470:d:cb4::2",
+        "default_inet6_interface" => "bridge0"
       }
     },
     "linux" => {
       "network" => {
-        # pp Hash[node['network']] from  shef to get the network data
+        # pp Hash[node['network']] from chef-shell to get the network data
         # have just removed the neighbour and route entries by hand
         "interfaces" => {
           "lo" => {
@@ -207,7 +228,8 @@ describe Ohai::System, "Network Plugin" do
               }
             },
             "mtu" => "16436",
-            "encapsulation" => "Loopback"
+            "encapsulation" => "Loopback",
+            "state" => "unknown"
           },
           "eth0" => {
             "flags" => ["BROADCAST", "MULTICAST", "UP"],
@@ -218,7 +240,9 @@ describe Ohai::System, "Network Plugin" do
                 "prefixlen" => "64",
                 "family" => "inet6"
               },
-              "00:16:3E:2F:36:79" => {"family" => "lladdr"},
+              "00:16:3E:2F:36:79" => {
+                "family" => "lladdr"
+              },
               "192.168.66.33" => {
                 "scope" => "Global",
                 "netmask" => "255.255.255.0",
@@ -229,7 +253,8 @@ describe Ohai::System, "Network Plugin" do
               "3ffe:1111:2222::33" => {
                 "prefixlen" => "48",
                 "family" => "inet6",
-                "scope" => "Global"
+                "scope" => "Global",
+                "state" => "up"
               }
             },
             "mtu" => "1500",
@@ -245,7 +270,9 @@ describe Ohai::System, "Network Plugin" do
                 "prefixlen" => "64",
                 "family" => "inet6"
               },
-              "00:16:3E:2F:36:80" => {"family" => "lladdr"},
+              "00:16:3E:2F:36:80" => {
+                "family" => "lladdr"
+              },
               "192.168.99.11" => {
                 "scope" => "Global",
                 "netmask" => "255.255.255.0",
@@ -301,14 +328,14 @@ describe Ohai::System, "Network Plugin" do
     }
   }
 
-  describe "with linux" do
+  describe "on linux" do
     before(:each) do
       @plugin = get_plugin("network")
       @plugin["network"] = basic_data["linux"]["network"]
     end
 
     describe "when the linux::network plugin hasn't set any of {ip,ip6,mac}address attributes" do
-      describe "simple setup" do
+      describe "simple network setup" do
         it_populates_ipaddress_attributes
 
         it "detects {ip,ip6,mac}address" do
@@ -363,10 +390,9 @@ describe Ohai::System, "Network Plugin" do
             expect(@plugin["ip6address"]).to eq("3ffe:1111:3333::1")
           end
 
-          it "doesn't set macaddress, ipv4 setup is valid and has precedence over ipv6" do
-            expect(Ohai::Log).not_to receive(:warn).with(/^unable to detect macaddress/)
+          it "sets macaddress to the ipv6 interface because it hadn't set one for ipv4 first" do
             @plugin.run
-            expect(@plugin["macaddress"]).to be_nil
+            expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:80")
           end
 
           it "informs about this setup" do
@@ -393,10 +419,11 @@ describe Ohai::System, "Network Plugin" do
             expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:80")
             expect(@plugin["ip6address"]).to eq("3ffe:1111:3333::1")
           end
-          
+
           it "warns about this conflict" do
             expect(Ohai::Log).to receive(:debug).with(/^\[inet\] no ipaddress\/mask on eth1/).once
             expect(Ohai::Log).to receive(:debug).with(/^\[inet6\] no ipaddress\/mask on eth1/).once
+            allow(Ohai::Log).to receive(:debug)
             @plugin.run
           end
         end
@@ -434,9 +461,9 @@ describe Ohai::System, "Network Plugin" do
 
           it "warns about this conflict" do
             expect(Ohai::Log).to receive(:warn).with(/^unable to detect ipaddress/).once
-            expect(Ohai::Log).to receive(:warn).with(/^unable to detect macaddress/).once
             expect(Ohai::Log).to receive(:warn).with(/^\[inet\] no ip address on eth0/).once
             expect(Ohai::Log).to receive(:debug).with(/^unable to detect ip6address/).once
+            expect(Ohai::Log).to receive(:debug).with(/^unable to detect macaddress/).twice # for each family
             expect(Ohai::Log).to receive(:warn).with(/^\[inet6\] no ip address on eth0/).once
             @plugin.run
           end
@@ -465,7 +492,7 @@ describe Ohai::System, "Network Plugin" do
 
           it "should warn about it" do
             expect(Ohai::Log).to receive(:warn).with(/^unable to detect ipaddress/).once
-            expect(Ohai::Log).to receive(:warn).with(/^unable to detect macaddress/).once
+            expect(Ohai::Log).to receive(:debug).with(/^unable to detect macaddress/).twice # for each family
             expect(Ohai::Log).to receive(:debug).with(/^unable to detect ip6address/).once
             @plugin.run
           end
@@ -769,7 +796,9 @@ describe Ohai::System, "Network Plugin" do
 
         it "warns about not being able to set {ip,mac}address (ipv4)" do
           expect(Ohai::Log).to receive(:warn).with(/^unable to detect ipaddress/).once
-          expect(Ohai::Log).to receive(:warn).with(/^unable to detect macaddress/).once
+          expect(Ohai::Log).to receive(:debug).with(/^unable to detect macaddress/) # for ipv4
+          expect(Ohai::Log).to receive(:debug).with(/^setting macaddress to/) # for ipv6
+          expect(Ohai::Log).to receive(:debug).with(/^\[inet6\] Using default interface eth0 and default gateway/) # for ipv6
           @plugin.run
         end
 
@@ -781,14 +810,46 @@ describe Ohai::System, "Network Plugin" do
         end
 
         it "informs about macaddress being set using the ipv6 setup" do
-          expect(Ohai::Log).to receive(:debug).with(/^macaddress set to 00:16:3E:2F:36:79 from the ipv6 setup/).once
+          expect(Ohai::Log).to receive(:debug).with(/^setting macaddress to '00:16:3E:2F:36:79'/)
           allow(Ohai::Log).to receive(:debug)
           @plugin.run
         end
       end
 
+      describe "ipv6 only with ipv4 loopback" do
+        before do
+          @plugin["network"]["default_gateway"] = nil
+          @plugin["network"]["default_interface"] = nil
+          @plugin["network"]["interfaces"].each do |i,iv|
+            next if i == 'lo'
+            iv["addresses"].delete_if{|k,kv| kv["family"] == "inet" }
+          end
+        end
+
+        it_doesnt_fail
+
+        it "can't detect ipaddress" do
+          allow(Ohai::Log).to receive(:warn)
+          @plugin.run
+          expect(@plugin["ipaddress"]).to eq("127.0.0.1")
+        end
+
+        it "sets {ip6,mac}address" do
+          allow(Ohai::Log).to receive(:warn)
+          @plugin.run
+          expect(@plugin["ip6address"]).to eq("3ffe:1111:2222::33")
+          expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:79")
+        end
+
+        it "informs about macaddress being set using the ipv6 setup" do
+          expect(Ohai::Log).to receive(:debug).with(/^setting macaddress to '00:16:3E:2F:36:79'/)
+          allow(Ohai::Log).to receive(:debug)
+          @plugin.run
+        end
+      end
     end
 
+    # specs using network plugin data for each mocked OS (freebsd,linux,windows)
     basic_data.keys.sort.each do |os|
       describe "the #{os}::network has already set some of the {ip,mac,ip6}address attributes" do
         before(:each) do
@@ -801,13 +862,16 @@ describe Ohai::System, "Network Plugin" do
             @plugin["macaddress"] = "00:AA:BB:CC:DD:EE"
             @expected_results = {
               "freebsd" => {
-                "ip6address" => "::1"
+                "ip6address" => "2001:470:d:cb4::1",
+                "macaddress" => "02:20:6f:d2:c4:00"
               },
               "linux" => {
-                "ip6address" => "3ffe:1111:2222::33"
+                "ip6address" => "3ffe:1111:2222::33",
+                "macaddress" => "00:16:3E:2F:36:79"
               },
               "windows" => {
-                "ip6address" => "fe80::698d:3e37:7950:b28c"
+                "ip6address" => "fe80::698d:3e37:7950:b28c",
+                "macaddress" => "00:AA:BB:CC:DD:EE"
               }
             }
           end
@@ -870,6 +934,17 @@ describe Ohai::System, "Network Plugin" do
                 end
               end
               @plugin["ip6address"] = "3ffe:8888:9999::1"
+              @expected_results = {
+                "freebsd" => {
+                  "macaddress" => "02:20:6f:d2:c4:00"
+                },
+                "linux" => {
+                  "macaddress" => "00:16:3E:2F:36:79"
+                },
+                "windows" => {
+                  "macaddress" => "52:54:44:66:66:02"
+                }
+              }
             end
 
             it_doesnt_fail
@@ -880,15 +955,14 @@ describe Ohai::System, "Network Plugin" do
               expect(@plugin["ipaddress"]).to be_nil
             end
 
-            it "can't detect macaddress either" do
+            it "takes the macaddress from ipv6" do
               allow(Ohai::Log).to receive(:warn)
               @plugin.run
-              expect(@plugin["macaddress"]).to be_nil
+              expect(@plugin["macaddress"]).to eq(@expected_results[os]["macaddress"])
             end
 
-            it "warns about not being able to set {ip,mac}address" do
+            it "warns about not being able to set ipaddress" do
               expect(Ohai::Log).to receive(:warn).with(/^unable to detect ipaddress/).once
-              expect(Ohai::Log).to receive(:warn).with(/^unable to detect macaddress/).once
               @plugin.run
             end
 
@@ -923,10 +997,10 @@ describe Ohai::System, "Network Plugin" do
 
             it_populates_ipaddress_attributes
 
-            it "detects ipaddress and overwrite macaddress" do
+            it "detects ipaddress and does not overwrite macaddress" do
               @plugin.run
               expect(@plugin["ipaddress"]).to eq(@expected_results[os]["ipaddress"])
-              expect(@plugin["macaddress"]).to eq(@expected_results[os]["macaddress"])
+              expect(@plugin["macaddress"]).to eq(@plugin["macaddress"])
             end
 
             it "doesn't overwrite ip6address" do
@@ -990,10 +1064,9 @@ describe Ohai::System, "Network Plugin" do
 
           it_doesnt_fail
 
-          it "doesn't overwrite {ip,mac,ip6}address" do
+          it "doesn't overwrite {ip,ip6}address" do
             @plugin.run
             expect(@plugin["ipaddress"]).to eq("10.11.12.13")
-            expect(@plugin["macaddress"]).to eq(nil)
             expect(@plugin["ip6address"]).to eq("3ffe:8888:9999::1")
           end
         end
