@@ -1,7 +1,7 @@
 #
-# Author:: Adam Jacob (<adam@opscode.com>)
-# Author:: Claire McQuin (<claire@opscode.com>)
-# Copyright:: Copyright (c) 2008, 2013 Opscode, Inc.
+# Author:: Adam Jacob (<adam@chef.io>)
+# Author:: Claire McQuin (<claire@chef.io>)
+# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,17 +26,87 @@ describe "Ohai::System" do
   let(:ohai) { Ohai::System.new }
 
   describe "#initialize" do
-    it "should return an Ohai::System object" do
+    it "returns an Ohai::System object" do
       expect(ohai).to be_a_kind_of(Ohai::System)
     end
 
-    it "should set @attributes to a ProvidesMap" do
+    it "sets @attributes to a ProvidesMap" do
       expect(ohai.provides_map).to be_a_kind_of(Ohai::ProvidesMap)
     end
 
-    it "should set @v6_dependency_solver to a Hash" do
+    it "sets @v6_dependency_solver to a Hash" do
       expect(ohai.v6_dependency_solver).to be_a_kind_of(Hash)
     end
+
+    it 'merges deprecated config settings into the ohai config context' do
+      expect(Ohai::Log).to receive(:warn).
+        with(/Ohai::Config\[:disabled_plugins\] is deprecated/)
+      Ohai::Config[:disabled_plugins] = [ :Foo, :Baz ]
+      expect(Ohai::Config).to receive(:merge_deprecated_config).
+        and_call_original
+      Ohai::System.new
+      expect(Ohai.config[:disabled_plugins]).to eq([ :Foo, :Baz ])
+    end
+
+    it 'merges provided configuration options into the ohai config context' do
+      config = {
+        disabled_plugins: [ :Foo, :Baz ],
+        directory: '/some/extra/plugins'
+      }
+      allow(Ohai::Config).to receive(:merge_deprecated_config)
+      expect(Ohai.config).to receive(:merge!).with(config).and_call_original
+      Ohai::System.new(config)
+      config.each do |option, value|
+        expect(Ohai.config[option]).to eq(value)
+      end
+    end
+
+    context 'when directory is configured' do
+      let(:directory) { '/some/fantastic/plugins' }
+
+      it 'adds directory to plugin_path' do
+        Ohai.config[:directory] = directory
+        Ohai::System.new
+        expect(Ohai.config[:plugin_path]).to include(directory)
+      end
+    end
+
+    shared_examples_for 'appendable deprecated configuration option' do
+      it 'logs a warning and configures the option on the ohai config context' do
+        Ohai::Config[option] << value
+        expect(Ohai::Log).to receive(:warn).
+          with(/Ohai::Config\[:#{option}\] is deprecated/)
+        Ohai::System.new
+        expect(Ohai.config[option]).to include(value)
+      end
+    end
+
+    context 'when a top-level hints_path is configured' do
+      include_examples 'appendable deprecated configuration option' do
+        let(:option) { :hints_path }
+        let(:value) { '/path/to/hints' }
+      end
+    end
+
+    context 'when a top-level plugin_path is configured' do
+      include_examples 'appendable deprecated configuration option' do
+        let(:option) { :plugin_path }
+        let(:value) { '/path/to/plugins' }
+      end
+    end
+
+    it 'configures logging' do
+      log_level = :debug
+      Ohai.config[:log_level] = log_level
+      expect(Ohai::Log).to receive(:init).with(Ohai.config[:log_location])
+      expect(Ohai::Log).to receive(:level=).with(log_level)
+      Ohai::System.new
+    end
+
+    it 'resolves log_level when set to :auto' do
+      expect(Ohai::Log).to receive(:level=).with(:info)
+      Ohai::System.new
+    end
   end
 
   when_plugins_directory "contains v6 and v7 plugins" do
@@ -51,8 +121,7 @@ provides 'fish'
 EOF
 
     before do
-      @original_config = Ohai::Config[:plugin_path]
-      Ohai::Config[:plugin_path] = [ path_to(".") ]
+      Ohai.config[:plugin_path] = [ path_to(".") ]
     end
 
     it "load_plugins() should load all the plugins" do
@@ -85,12 +154,7 @@ provides 'bear'
 EOF
 
     before do
-      @original_config = Ohai::Config[:plugin_path]
-      Ohai::Config[:plugin_path] = [ path_to("repo1"), path_to("repo2") ]
-    end
-
-    after do
-      Ohai::Config[:plugin_path] = @original_config
+      Ohai.config[:plugin_path] = [ path_to("repo1"), path_to("repo2") ]
     end
 
     it "load_plugins() should load all the plugins" do
@@ -106,14 +170,6 @@ EOF
   end
 
   describe "when running plugins" do
-    before do
-      @original_config = Ohai::Config[:plugin_path]
-    end
-
-    after do
-      Ohai::Config[:plugin_path] = @original_config
-    end
-
     when_plugins_directory "contains v6 plugins only" do
       with_plugin("zoo.rb", <<EOF)
 provides 'zoo'
@@ -126,7 +182,7 @@ park("plants")
 EOF
 
       it "should collect data from all the plugins" do
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
+        Ohai.config[:plugin_path] = [ path_to(".") ]
         ohai.all_plugins
         expect(ohai.data[:zoo]).to eq("animals")
         expect(ohai.data[:park]).to eq("plants")
@@ -134,15 +190,15 @@ EOF
 
       describe "when using :disabled_plugins" do
         before do
-          Ohai::Config[:disabled_plugins] = [ "zoo" ]
+          Ohai.config[:disabled_plugins] = [ "zoo" ]
         end
 
         after do
-          Ohai::Config[:disabled_plugins] = [ ]
+          Ohai.config[:disabled_plugins] = [ ]
         end
 
         it "shouldn't run disabled version 6 plugins" do
-          Ohai::Config[:plugin_path] = [ path_to(".") ]
+          Ohai.config[:plugin_path] = [ path_to(".") ]
           ohai.all_plugins
           expect(ohai.data[:zoo]).to be_nil
           expect(ohai.data[:park]).to eq("plants")
@@ -245,7 +301,7 @@ end
 EOF
 
       it "should collect platform specific" do
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
+        Ohai.config[:plugin_path] = [ path_to(".") ]
         ohai.all_plugins
         expect(ohai.data[:message]).to eq("platform_specific_message")
       end
@@ -272,14 +328,14 @@ end
 EOF
 
       it "should collect data from all the plugins" do
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
+        Ohai.config[:plugin_path] = [ path_to(".") ]
         ohai.all_plugins
         expect(ohai.data[:zoo]).to eq("animals")
         expect(ohai.data[:park]).to eq("plants")
       end
 
       it "should write an error to Ohai::Log" do
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
+        Ohai.config[:plugin_path] = [ path_to(".") ]
         # Make sure the stubbing of runner is not overriden with reset_system during test
         allow(ohai).to receive(:reset_system)
         allow(ohai.instance_variable_get("@runner")).to receive(:run_plugin).and_raise(Ohai::Exceptions::AttributeNotFound)
@@ -289,15 +345,15 @@ EOF
 
       describe "when using :disabled_plugins" do
         before do
-          Ohai::Config[:disabled_plugins] = [ :Zoo ]
+          Ohai.config[:disabled_plugins] = [ :Zoo ]
         end
 
         after do
-          Ohai::Config[:disabled_plugins] = [ ]
+          Ohai.config[:disabled_plugins] = [ ]
         end
 
         it "shouldn't run disabled plugins" do
-          Ohai::Config[:plugin_path] = [ path_to(".") ]
+          Ohai.config[:plugin_path] = [ path_to(".") ]
           ohai.all_plugins
           expect(ohai.data[:zoo]).to be_nil
           expect(ohai.data[:park]).to eq("plants")
@@ -338,15 +394,15 @@ EOF
 
       describe "when using :disabled_plugins" do
         before do
-          Ohai::Config[:disabled_plugins] = [ :Zoo, 'my_plugins::park' ]
+          Ohai.config[:disabled_plugins] = [ :Zoo, 'my_plugins::park' ]
         end
 
         after do
-          Ohai::Config[:disabled_plugins] = [ ]
+          Ohai.config[:disabled_plugins] = [ ]
         end
 
         it "shouldn't run disabled plugins" do
-          Ohai::Config[:plugin_path] = [ path_to(".") ]
+          Ohai.config[:plugin_path] = [ path_to(".") ]
           ohai.all_plugins
           expect(ohai.data[:zoo]).to be_nil
           expect(ohai.data[:nature]).to eq("cougars")
@@ -384,12 +440,7 @@ end
 EOF
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-         Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "should collect all data" do
@@ -427,12 +478,7 @@ end
 EOF
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-         Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "version 6 should run" do
@@ -475,12 +521,7 @@ end
 EOF
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-         Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "should collect all the data properly" do
@@ -502,12 +543,7 @@ message v7message
 EOF
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-         Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "should raise DependencyNotFound" do
@@ -525,12 +561,7 @@ EOF
       E
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-        Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "reloads only the v6 plugin when given a specific plugin to load" do
@@ -552,12 +583,7 @@ EOF
       E
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-        Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "should rerun the plugin providing the desired attributes" do
@@ -611,17 +637,12 @@ EOF
       E
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
+        Ohai.config[:plugin_path] = [ path_to(".") ]
         Ohai::Log.init(STDOUT)
         Ohai::Log.level = :debug
         ohai.all_plugins
       end
 
-      after do
-        Ohai::Config[:plugin_path] = @original_config
-      end
-
       it "should rerun the plugin providing the desired attributes" do
         expect(ohai.data[:desired_attr_count]).to eq(1)
         ohai.refresh_plugins("desired_attr")
@@ -682,12 +703,7 @@ EOF
       E
 
       before do
-        @original_config = Ohai::Config[:plugin_path]
-        Ohai::Config[:plugin_path] = [ path_to(".") ]
-      end
-
-      after do
-        Ohai::Config[:plugin_path] = @original_config
+        Ohai.config[:plugin_path] = [ path_to(".") ]
       end
 
       it "should run all the plugins when a top level attribute is specified" do
